==> rest-sdk-0.1.3-HF1-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/validation/util/ValidationUtils.java <==
/*
 * (c) 2003-2020 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.validation.util;

import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorOperation;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.ConnectorDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.DescriptorElement;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.EndPointDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.OperationDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.TriggerDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.APIModel;
import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.APIOperationModel;

public class ValidationUtils {

  public static EndPointDescriptor getEndpointDescriptor(ConnectorDescriptor connectorDescriptor,
                                                         APIOperationModel apiOperationModel) {
    return connectorDescriptor.getEndpoints().stream()
        .filter(x -> x.getPath().equalsIgnoreCase(apiOperationModel.getPath()))
        .findFirst()
        .orElse(null);
  }

  public static OperationDescriptor getOperationDescriptor(EndPointDescriptor endPointDescriptor,
                                                           APIOperationModel apiOperationModel) {
    return endPointDescriptor.getOperations().stream()
        .filter(x -> x.getMethod().equalsIgnoreCase(apiOperationModel.getHttpMethod()))
        .findFirst().orElse(null);
  }

  public static DescriptorElement getClosestDescriptorElement(ConnectorDescriptor connectorDescriptor,
                                                              APIOperationModel apiOperationModel) {
    final EndPointDescriptor endpointDescriptor = getEndpointDescriptor(connectorDescriptor, apiOperationModel);

    if (endpointDescriptor == null) {
      return connectorDescriptor;
    }

    OperationDescriptor operationDescriptor = getOperationDescriptor(endpointDescriptor, apiOperationModel);
    if (operationDescriptor == null) {
      return endpointDescriptor;
    }

    return operationDescriptor;
  }

  public static EndPointDescriptor getEndpointDescriptor(ConnectorDescriptor connectorDescriptor,
                                                         ConnectorOperation connectorOperation) {
    return connectorDescriptor.getEndpoints().stream()
        .filter(x -> x.getPath().equalsIgnoreCase(connectorOperation.getPath()))
        .findFirst()
        .orElse(null);
  }

  public static OperationDescriptor getOperationDescriptor(EndPointDescriptor endPointDescriptor,
                                                           ConnectorOperation connectorOperation) {
    return endPointDescriptor.getOperations().stream()
        .filter(x -> x.getMethod().equalsIgnoreCase(connectorOperation.getHttpMethod()))
        .findFirst().orElse(null);
  }

  public static DescriptorElement getClosestDescriptorElement(ConnectorDescriptor connectorDescriptor,
                                                              ConnectorOperation connectorOperation) {
    final EndPointDescriptor endpointDescriptor = getEndpointDescriptor(connectorDescriptor, connectorOperation);

    if (endpointDescriptor == null) {
      return connectorDescriptor;
    }

    OperationDescriptor operationDescriptor = getOperationDescriptor(endpointDescriptor, connectorOperation);
    if (operationDescriptor == null) {
      return endpointDescriptor;
    }

    return operationDescriptor;
  }

  public static APIOperationModel getApiOperationModel(APIModel apiModel, ConnectorOperation connectorOperation) {
    return apiModel.getOperationsModel().stream()
        .filter(x -> connectorOperation.getPath().equalsIgnoreCase(x.getPath()))
        .filter(x -> connectorOperation.getHttpMethod().equalsIgnoreCase(x.getHttpMethod()))
        .findFirst().orElse(null);
  }

  public static APIOperationModel getApiOperation(APIModel apiModel, TriggerDescriptor triggerDescriptor) {
    return apiModel.getOperationsModel().stream()
        .filter(x -> x.getPath().equalsIgnoreCase(triggerDescriptor.getPath()))
        .filter(x -> x.getHttpMethod().equalsIgnoreCase(triggerDescriptor.getMethod().getName()))
        .findFirst().orElse(null);
  }

  public static OperationDescriptor getOperationDescriptor(ConnectorDescriptor connectorDescriptor,
                                                           APIOperationModel apiOperation) {
    return connectorDescriptor.getEndpoints().stream()
        .filter(x -> x.getPath().equalsIgnoreCase(apiOperation.getPath()))
        .flatMap(x -> x.getOperations().stream())
        .filter(x -> x.getMethod().equalsIgnoreCase(apiOperation.getHttpMethod()))
        .findFirst().orElse(null);
  }
}

==> rest-sdk-0.2.1-HF1-sources.jar: com/mulesoft/connectivity/rest/sdk/internal/validation/util/ValidationUtils.java <==
/*
 * (c) 2003-2021 MuleSoft, Inc. This software is protected under international copyright
 * law. All use of this software is subject to MuleSoft's Master Subscription Agreement
 * (or other master license agreement) separately entered into in writing between you and
 * MuleSoft. If such an agreement is not in place, you may not use the software.
 */
package com.mulesoft.connectivity.rest.sdk.internal.validation.util;

import static java.util.stream.Collectors.toList;

import com.mulesoft.connectivity.rest.sdk.internal.connectormodel.ConnectorOperation;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.ConnectorDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.DescriptorElement;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.EndPointDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.OperationDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.ParameterDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.RequestDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.TriggerDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.resolvers.ResolverReferenceDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.descriptor.model.valueprovider.ValueProviderDefinitionDescriptor;
import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.APIModel;
import com.mulesoft.connectivity.rest.sdk.internal.webapi.model.APIOperationModel;

import java.util.ArrayList;
import java.util.List;

public class ValidationUtils {

  public static EndPointDescriptor getEndpointDescriptor(ConnectorDescriptor connectorDescriptor,
                                                         APIOperationModel apiOperationModel) {
    return connectorDescriptor.getEndpoints().stream()
        .filter(x -> x.getPath().equalsIgnoreCase(apiOperationModel.getPath()))
        .findFirst()
        .orElse(null);
  }

  public static OperationDescriptor getOperationDescriptor(EndPointDescriptor endPointDescriptor,
                                                           APIOperationModel apiOperationModel) {
    return endPointDescriptor.getOperations().stream()
        .filter(x -> x.getMethod().equalsIgnoreCase(apiOperationModel.getHttpMethod()))
        .findFirst().orElse(null);
  }

  public static DescriptorElement getClosestDescriptorElement(ConnectorDescriptor connectorDescriptor,
                                                              APIOperationModel apiOperationModel) {
    final EndPointDescriptor endpointDescriptor = getEndpointDescriptor(connectorDescriptor, apiOperationModel);

    if (endpointDescriptor == null) {
      return connectorDescriptor;
    }

    OperationDescriptor operationDescriptor = getOperationDescriptor(endpointDescriptor, apiOperationModel);
    if (operationDescriptor == null) {
      return endpointDescriptor;
    }

    return operationDescriptor;
  }

  public static EndPointDescriptor getEndpointDescriptor(ConnectorDescriptor connectorDescriptor,
                                                         ConnectorOperation connectorOperation) {
    return connectorDescriptor.getEndpoints().stream()
        .filter(x -> x.getPath().equalsIgnoreCase(connectorOperation.getPath()))
        .findFirst()
        .orElse(null);
  }

  public static OperationDescriptor getOperationDescriptor(EndPointDescriptor endPointDescriptor,
                                                           ConnectorOperation connectorOperation) {
    return endPointDescriptor.getOperations().stream()
        .filter(x -> x.getMethod().equalsIgnoreCase(connectorOperation.getHttpMethod().name()))
        .findFirst().orElse(null);
  }

  public static DescriptorElement getClosestDescriptorElement(ConnectorDescriptor connectorDescriptor,
                                                              ConnectorOperation connectorOperation) {
    final EndPointDescriptor endpointDescriptor = getEndpointDescriptor(connectorDescriptor, connectorOperation);

    if (endpointDescriptor == null) {
      return connectorDescriptor;
    }

    OperationDescriptor operationDescriptor = getOperationDescriptor(endpointDescriptor, connectorOperation);
    if (operationDescriptor == null) {
      return endpointDescriptor;
    }

    return operationDescriptor;
  }

  public static APIOperationModel getApiOperationModel(APIModel apiModel, ConnectorOperation connectorOperation) {
    return apiModel.getOperationsModel().stream()
        .filter(x -> connectorOperation.getPath().equalsIgnoreCase(x.getPath()))
        .filter(x -> connectorOperation.getHttpMethod().name().equalsIgnoreCase(x.getHttpMethod()))
        .findFirst().orElse(null);
  }

  public static APIOperationModel getApiOperation(APIModel apiModel, TriggerDescriptor triggerDescriptor) {
    return apiModel.getOperationsModel().stream()
        .filter(x -> x.getPath().equalsIgnoreCase(triggerDescriptor.getPath()))
        .filter(x -> x.getHttpMethod().equalsIgnoreCase(triggerDescriptor.getMethod().getName()))
        .findFirst().orElse(null);
  }

  public static OperationDescriptor getOperationDescriptor(ConnectorDescriptor connectorDescriptor,
                                                           APIOperationModel apiOperation) {
    return connectorDescriptor.getEndpoints().stream()
        .filter(x -> x.getPath().equalsIgnoreCase(apiOperation.getPath()))
        .flatMap(x -> x.getOperations().stream())
        .filter(x -> x.getMethod().equalsIgnoreCase(apiOperation.getHttpMethod()))
        .findFirst().orElse(null);
  }

  public static List<ResolverReferenceDescriptor<ValueProviderDefinitionDescriptor>> getValueProviderReferenceDescriptors(
                                                                                                                          ConnectorDescriptor connectorDescriptor) {

    return connectorDescriptor.getEndpoints().stream()
        .flatMap(x -> x.getOperations().stream())
        .flatMap(x -> getValueProviderReferenceDescriptors(x).stream())
        .collect(toList());
  }

  public static List<ResolverReferenceDescriptor<ValueProviderDefinitionDescriptor>> getValueProviderReferenceDescriptors(
                                                                                                                          OperationDescriptor operationDescriptor) {

    return getAllParameters(operationDescriptor.getExpects()).stream()
        .map(ParameterDescriptor::getValueProvider)
        .filter(x -> x instanceof ResolverReferenceDescriptor<?>)
        .map(x -> (ResolverReferenceDescriptor<ValueProviderDefinitionDescriptor>) x)
        .collect(toList());
  }

  public static APIOperationModel getApiOperationModel(APIModel apiModel, EndPointDescriptor endpointDescriptor,
                                                       OperationDescriptor operationDescriptor) {
    return apiModel.getOperationsModel().stream()
        .filter(x -> x.getPath().equalsIgnoreCase(endpointDescriptor.getPath()))
        .filter(x -> x.getHttpMethod().equalsIgnoreCase(operationDescriptor.getMethod()))
        .findFirst().orElse(null);
  }

  private static List<ParameterDescriptor> getAllParameters(RequestDescriptor requestDescriptor) {
    List<ParameterDescriptor> parameters = new ArrayList<>();

    if (requestDescriptor != null) {
      parameters.addAll(requestDescriptor.getUriParameter());
      parameters.addAll(requestDescriptor.getQueryParameter());
      parameters.addAll(requestDescriptor.getHeader());
    }

    return parameters;
  }
}
